import {type GridColDef} from '@mui/x-data-grid'
import {CustomDataGrid} from '../../components/CustomDataGrid'
import {DeleteButton, EditButton, List, ShowButton, useDataGrid} from '@refinedev/mui'
import React from 'react'

export const CarrierList = () => {
  const {dataGridProps} = useDataGrid({})

  const columns = React.useMemo<GridColDef[]>(
    () => [
      {
        field: 'id',
        headerName: 'ID',
        type: 'number',
        minWidth: 50,
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'city_id',
        headerName: 'ID Города',
        type: 'number',
        minWidth: 100,
        align: 'left',
        headerAlign: 'left',
      },
      {
        field: 'full_name',
        headerName: 'Полное имя',
        type: 'string',
        minWidth: 200,
      },
      {
        field: 'short_name',
        headerName: 'Короткое имя',
        type: 'string',
        minWidth: 150,
      },
      {
        field: 'city',
        headerName: 'Город',
        type: 'string',
        minWidth: 150,
        align: 'left',
        headerAlign: 'left',
        flex: 1,
      },
      {
        field: 'actions',
        headerName: 'Действия',
        minWidth: 120,
        display: 'flex',
        align: 'right',
        headerAlign: 'center',
        sortable: false,
        filterable: false,
        disableColumnMenu: true,
        renderCell: function render({row}) {
          return (
            <>
              <EditButton hideText recordItemId={row.id} />
              <ShowButton hideText recordItemId={row.id} />
              <DeleteButton hideText confirmTitle="Вы уверены?" recordItemId={row.id} />
            </>
          )
        },
      },
    ],
    [],
  )

  return (
    <List>
      <CustomDataGrid {...dataGridProps} columns={columns} />
    </List>
  )
}
